@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for GNU Prolog 1.4.5 (and later versions)
-%  Last updated on July 14, 2021
+%  Last updated on August 19, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -512,20 +512,16 @@ setup_call_cleanup(_, _, _) :-
 % '$lgt_prolog_term_expansion'(@callable, -callable)
 
 '$lgt_prolog_term_expansion'((:- Directive), Expanded) :-
-	'$lgt_gnu_directive_expansion'(Directive, Expanded0),
-	(	Expanded0 == [] ->
-		Expanded  == []
-	;	Expanded0 =  {ExpandedDirective} ->
-		Expanded  =  {(:- ExpandedDirective)}
-	;	Expanded  =  (:- Expanded0)
-	).
+	nonvar(Directive),
+	% allow first-argument indexing
+	'$lgt_gnu_directive_expansion'(Directive, Expanded).
 
-'$lgt_gnu_directive_expansion'(built_in, {built_in}) :-
+'$lgt_gnu_directive_expansion'(built_in, {:- built_in}) :-
 	\+ logtalk_load_context(entity_type, _).
-'$lgt_gnu_directive_expansion'(built_in_fd, {built_in_fd}).
-'$lgt_gnu_directive_expansion'(foreign(Template, Options), {foreign(Template, Options)}).
-'$lgt_gnu_directive_expansion'(foreign(Template), {foreign(Template)}).
-'$lgt_gnu_directive_expansion'(op(Priority, Specifier, ':'(Module,Operators)), {op(Priority, Specifier, Operators)}) :-
+'$lgt_gnu_directive_expansion'(built_in_fd, {:- built_in_fd}).
+'$lgt_gnu_directive_expansion'(foreign(Template, Options), {:- foreign(Template, Options)}).
+'$lgt_gnu_directive_expansion'(foreign(Template), {:- foreign(Template)}).
+'$lgt_gnu_directive_expansion'(op(Priority, Specifier, ':'(Module,Operators)), {:- op(Priority, Specifier, Operators)}) :-
 	Module == user.
 
 
