@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for LVM 1.7.0 and later versions
-%  Last updated on July 14, 2021
+%  Last updated on August 31, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -185,6 +185,8 @@ setup_call_cleanup(_, _, _) :-
 '$lgt_prolog_predicate_property'(last_modified_generation(_)).
 '$lgt_prolog_predicate_property'(foreign).
 '$lgt_prolog_predicate_property'(number_of_clauses(_)).
+'$lgt_prolog_predicate_property'(spy).
+'$lgt_prolog_predicate_property'(disk_predicate(_)).
 
 
 
@@ -506,14 +508,26 @@ setup_call_cleanup(_, _, _) :-
 
 % '$lgt_prolog_term_expansion'(@callable, -callable)
 
-'$lgt_prolog_term_expansion'(_, _) :-
-	fail.
+'$lgt_prolog_term_expansion'((:- Directive), Expanded) :-
+	nonvar(Directive),
+	% allow first-argument indexing
+	catch('$lgt_lvm_directive_expansion'(Directive, Expanded), _, fail).
+
+'$lgt_lvm_directive_expansion'(disk_predicate(Template,Mode,Database), [{:- disk_predicate(CTemplate,Mode,Database)}, (:- dynamic(Functor/Arity))]) :-
+	logtalk_load_context(entity_type, _),
+	'$lgt_compile_predicate_heads'(Template, _, CTemplate, ignore),
+	functor(Template, Functor, Arity).
 
 
 % '$lgt_prolog_goal_expansion'(@callable, -callable)
 
-'$lgt_prolog_goal_expansion'(_, _) :-
-	fail.
+'$lgt_prolog_goal_expansion'(define_disk_predicate(Template,Mode,Database), {define_disk_predicate(CTemplate,Mode,Database)}) :-
+	logtalk_load_context(entity_type, _),
+	'$lgt_compile_predicate_heads'(Template, _, CTemplate, ignore).
+
+'$lgt_prolog_goal_expansion'(destroy_disk_predicate(Functor/Arity), {destroy_disk_predicate(CFunctor/CArity)}) :-
+	logtalk_load_context(entity_type, _),
+	'$lgt_compile_predicate_indicators'(Functor/Arity, _, CFunctor/CArity).
 
 
 
