@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Adapter file for Trealla Prolog 1.9.38 and later versions
-%  Last updated on July 16, 2021
+%  Adapter file for Trealla Prolog 1.11.25 and later versions
+%  Last updated on August 27, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -64,13 +64,11 @@
 % format(+stream_or_alias, +character_code_list_or_atom, +list)
 % format(+character_code_list_or_atom, +list)
 
-:- use_module(library(format)).
-
 '$lgt_format'(Stream, Format, Arguments) :-
-	format(Stream, Format, Arguments), !.
+	format(Stream, Format, Arguments).
 
 '$lgt_format'(Format, Arguments) :-
-	format(Format, Arguments), !.
+	format(Format, Arguments).
 
 
 % numbervars(?term, +integer, ?integer) -- built-in
@@ -222,7 +220,7 @@
 '$lgt_prolog_feature'(prolog_dialect, trealla).
 '$lgt_prolog_feature'(prolog_version, v(Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, trealla(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(1, 9, 38))).
+'$lgt_prolog_feature'(prolog_compatible_version, '@>='(v(1, 11, 25))).
 
 '$lgt_prolog_feature'(encoding_directive, source).
 '$lgt_prolog_feature'(tabling, unsupported).
@@ -522,6 +520,7 @@
 % '$lgt_prolog_term_expansion'(@callable, -callable)
 
 '$lgt_prolog_term_expansion'((:- Directive), Expanded) :-
+	nonvar(Directive),
 	% allow first-argument indexing
 	catch('$lgt_trealla_directive_expansion'(Directive, Expanded), _, fail).
 
