@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for ProscriptLS 1.5.9 and later versions
-%  Last updated on June 21, 2021
+%  Last updated on July 14, 2021
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2021 Paulo Moura <pmoura@logtalk.org>
@@ -358,18 +358,20 @@
 	).
 
 
-% '$lgt_directory_hash_as_atom'(+atom, -atom)
+% '$lgt_directory_hash_dialect_as_atom'(+atom, -atom)
 %
-% returns the directory hash as an atom
+% returns the directory hash and dialect as an atom with the format _hash_dialect
 
-'$lgt_directory_hash_as_atom'(_, '').
+'$lgt_directory_hash_dialect_as_atom'(_, Hash) :-
+	'$lgt_prolog_feature'(prolog_dialect, Dialect),
+	atom_concat('_', Dialect, Hash).
 
 
 % '$lgt_directory_hash_pid_as_atom'(+atom, -atom)
 %
-% returns the directory hash and PID as an atom
+% returns the directory hash and PID as an atom with the format _hash_pid
 
-'$lgt_directory_hash_pid_as_atom'(_, '').
+'$lgt_directory_hash_pid_as_atom'(_, '_').
 
 
 % '$lgt_compile_prolog_code'(+atom, +atom, +list)
